@@ -70,7 +70,7 @@ def prepare_description(sensor):
         description["device_class"] = "power"
         description["unit_of_measurement"] = "W"
     if "enegy" in sensor or "energy" in sensor:  # typo in ess json
-        description["unit_of_measuremnt"] = "Wh"
+        description["unit_of_measurement"] = "Wh"
         description["icon"] = "mdi:gauge"
     if "soc" in sensor:
         description["device_class"] = "battery"
@@ -83,23 +83,19 @@ def prepare_description(sensor):
     return description
 
 
-async def announce_loop(client, once=False, sensors=None):
+async def announce_loop(client, sensors=None):
     if sensors is None:
         return
-    while True:
-        for sensor in sensors:
-            try:
-                await client.publish(f"homeassistant/sensor/{sensor.replace('/', '')}/config",
-                                     json.dumps(prepare_description(sensor)))
-            except (asyncio_mqtt.error.MqttCodeError, TimeoutError): # pragma: no cover
-                logger.warning("Lost MQTT connection to mqtt errorcode in announce loop, send loop will exit")
-            except:  # pragma: no cover
-                logger.exception(f"Lost MQTT connection to unexpected error code, restarting", exc_info=True)
-                raise
-        if not once:
-            await asyncio.sleep(120)
-        else:
-            return
+
+    for sensor in sensors:
+        try:
+            await client.publish(f"homeassistant/sensor/{sensor.replace('/', '')}/config",
+                                 json.dumps(prepare_description(sensor)), retain=True, qos=2)
+        except (asyncio_mqtt.error.MqttCodeError, TimeoutError): # pragma: no cover
+            logger.warning("Lost MQTT connection to mqtt errorcode in announce loop, send loop will exit")
+        except:  # pragma: no cover
+            logger.exception(f"Lost MQTT connection to unexpected error code, restarting", exc_info=True)
+            raise
 
 
 def main(arguments=None):
@@ -108,7 +104,8 @@ def main(arguments=None):
     # .run(_main, arguments)
 
 
-async def _main(arguments=None):
+async def _main( arguments=None):
+    loop = asyncio.get_event_loop()
     parser = configargparse.ArgumentParser(prog='essmqtt', description='Mqtt connector for pyess',
                                            add_config_file_help=True,
                                            default_config_files=['/etc/essmqtt.conf', '~/.essmqtt.conf'],
@@ -134,7 +131,7 @@ async def _main(arguments=None):
 
     args = parser.parse_args(arguments)
     if args.ess_host is None:
-        ip, name = autodetect_ess()
+        ip, name = await loop.run_in_executor(None, autodetect_ess)
     else:
         ip, name = args.ess_host, args.ess_host
 
@@ -168,7 +165,7 @@ async def _main(arguments=None):
             async for msg in messages:
                 logger.info(f"control message received {msg}")
                 try:
-                    state = strtobool(msg.decode())
+                    state = strtobool(msg.payload.decode())
                     await control(state)
                 except ValueError:
                     logger.warning(f"ignoring incompatible value {msg} for switching")
@@ -210,7 +207,7 @@ async def launch_main_loop(args, ess, handle_control, switch_active, switch_fast
         asyncio.create_task(handle_control(client, switch_active, "ess/control/active"))
         if args.hass_autoconfig_sensors is not None:
             asyncio.ensure_future(
-                announce_loop(client, once=args.once, sensors=args.hass_autoconfig_sensors.split(",")))
+                announce_loop(client, sensors=args.hass_autoconfig_sensors.split(",")))
 
         await send_loop(ess, client, once=args.once, interval_seconds=args.interval_seconds,
                         common_divisor=args.common_divisor)
